import { JokeFactory } from './JokeFactory';
import { CustomJoke } from './CustomJoke';
import { SampleJoke } from './SampleJoke';
import {describe, expect, it} from "@jest/globals";

describe('JokeFactory', () => {
    describe('createCustomJokes', () => {
        it('should create CustomJoke instances from JSON array', () => {
            const jsonArray = '[{"id": "1", "type": "Type1", "setup": "Setup1", "punchline": "Punchline1", "image": "Image1"}, {"id": "2", "type": "Type2", "setup": "Setup2", "punchline": "Punchline2", "image": "Image2"}]';
            const customJokes: CustomJoke[] = JokeFactory.createCustomJokes(jsonArray);

            expect(customJokes).toHaveLength(2);
            expect(customJokes[0]).toBeInstanceOf(CustomJoke);
            expect(customJokes[0].id).toBe('1');
            expect(customJokes[0].type).toBe('Type1');
        });

        it('should return an empty array if JSON array is empty', () => {
            const jsonArray = '[]';
            const customJokes: CustomJoke[] = JokeFactory.createCustomJokes(jsonArray);

            expect(customJokes).toHaveLength(0);
        });
    });

    describe('createSampleJokes', () => {
        it('should create SampleJoke instances from JSON array', () => {
            const jsonArray = '[{"id": 1, "type": "Type1", "setup": "Setup1", "punchline": "Punchline1", "image": "Image1"}, {"id": 2, "type": "Type2", "setup": "Setup2", "punchline": "Punchline2", "image": "Image2"}]';
            const sampleJokes: SampleJoke[] = JokeFactory.createSampleJokes(jsonArray);

            expect(sampleJokes).toHaveLength(2);
            expect(sampleJokes[0]).toBeInstanceOf(SampleJoke);
            expect(sampleJokes[0].id).toBe(1);
            expect(sampleJokes[0].type).toBe('Type1');
        });

        it('should return an empty array if JSON array is empty', () => {
            const jsonArray = '[]';
            const sampleJokes: SampleJoke[] = JokeFactory.createSampleJokes(jsonArray);

            expect(sampleJokes).toHaveLength(0);
        });
    });
});
