import React from 'react';
import { render, fireEvent } from '@testing-library/react-native';
import AddScreen, { themeSettings } from './AddScreen';
import { Provider } from 'react-redux';
import store from '../redux/store';
import {describe, expect, it} from "@jest/globals";

describe('<AddScreen />', () => {
    it('renders correctly', () => {
        const { getByText, getByPlaceholderText } = render(
            <Provider store={store}>
                <AddScreen />
            </Provider>
        );

        expect(getByText('Blague')).toBeTruthy();
        expect(getByPlaceholderText('Inserez votre blague')).toBeTruthy();
        expect(getByText('Chute de la blague')).toBeTruthy();
        expect(getByPlaceholderText('Inserez votre blague')).toBeTruthy();
        expect(getByText('Catégorie')).toBeTruthy();
        expect(getByPlaceholderText('Inserez votre blague')).toBeTruthy();
        expect(getByText('CRÉER')).toBeTruthy();
        expect(getByText('EFFACER')).toBeTruthy();
    });

    it('handles text input correctly', () => {
        const { getByPlaceholderText } = render(
            <Provider store={store}>
                <AddScreen />
            </Provider>
        );

        const jokeInput = getByPlaceholderText('Inserez votre blague');
        const downgradeInput = getByPlaceholderText('Inserez votre blague');
        const categoryInput = getByPlaceholderText('Inserez votre blague');

        fireEvent.changeText(jokeInput, 'This is a joke');
        fireEvent.changeText(downgradeInput, 'This is a downgrade');
        fireEvent.changeText(categoryInput, 'Funny');

        expect(jokeInput.props.value).toBe('This is a joke');
        expect(downgradeInput.props.value).toBe('This is a downgrade');
        expect(categoryInput.props.value).toBe('Funny');
    });

});

describe('themeSettings()', () => {
    it('returns correct styles for light theme', () => {
        const theme = {
            colors: {
                background: 'white',
                card: 'lightgrey',
                text: 'black',
                primary: 'blue',
            },
        };

        const styles = themeSettings(theme);
        expect(styles.container.backgroundColor).toBe('white');
        expect(styles.textInput.backgroundColor).toBe('lightgrey');
        expect(styles.text.color).toBe('black');
        expect(styles.eraseButton.backgroundColor).toBe('blue');
        expect(styles.createButton.backgroundColor).toBe('blue');
    });
});
