import React from 'react';
import { render, fireEvent } from '@testing-library/react-native';
import Favorites, { themeSettings } from './Favorites';
import { Provider } from 'react-redux';
import store from '../redux/store';
import {describe, expect, it} from "@jest/globals"; // Assuming you have a configured Redux store

describe('<Favorites />', () => {
    it('renders correctly', () => {
        const { getByText, getByTestId } = render(
            <Provider store={store}>
                <Favorites />
            </Provider>
        );

        expect(getByText('Afficher les exemples')).toBeTruthy();
        expect(getByTestId('toggle-button')).toBeTruthy();
    });

    it('toggles jokes display correctly', () => {
        const { getByTestId } = render(
            <Provider store={store}>
                <Favorites />
            </Provider>
        );

        const toggleButton = getByTestId('toggle-button');

        fireEvent.press(toggleButton);

        expect(toggleButton.props.children.props.source).toEqual(hideEye);

        fireEvent.press(toggleButton);

        expect(toggleButton.props.children.props.source).toEqual(eye);
    });
});

describe('themeSettings()', () => {
    it('returns correct styles for light theme', () => {
        const theme = {
            colors: {
                background: 'white',
                primary: 'blue',
                text: 'black',
                notification: 'grey',
            },
        };

        const styles = themeSettings(theme);
        expect(styles.container.backgroundColor).toBe('white');
        expect(styles.Button.backgroundColor).toBe('white');
        expect(styles.TextButton.color).toBe('grey');
        expect(styles.imageButton.tintColor).toBe('grey');
    });

});
