import React from 'react';
import { render, fireEvent } from '@testing-library/react-native';
import Settings, { themeSettings } from './Settings';
import { Provider } from 'react-redux';
import store from '../redux/store';
import {describe, expect, it} from "@jest/globals";

describe('<Settings />', () => {
    it('renders correctly', () => {
        const { getByTestId } = render(
            <Provider store={store}>
                <Settings />
            </Provider>
        );

        expect(getByTestId('settings-title')).toBeTruthy();
        expect(getByTestId('settings-switch')).toBeTruthy();
    });

    it('switches between light and dark mode', () => {
        const { getByTestId } = render(
            <Provider store={store}>
                <Settings />
            </Provider>
        );

        const switchElement = getByTestId('settings-switch');

        expect(switchElement.props.value).toBeFalsy();

        fireEvent(switchElement, 'onValueChange', true);

        expect(switchElement.props.value).toBeTruthy();
    });
});

describe('themeSettings()', () => {
    it('returns correct styles', () => {
        const theme = {
            colors: {
                background: 'white',
                text: 'black',
                primary: 'blue',
                card: 'gray',
            },
        };

        const styles = themeSettings(theme);
        expect(styles.container.backgroundColor).toBe('white');
        expect(styles.title.color).toBe('black');
    });

});
